#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 refact
version:              0.3.0.2
visibility:           public
id:                   refact-0.3.0.2-JKNk3jm7RIRD7pQxWgpJCE
key:                  refact-0.3.0.2-JKNk3jm7RIRD7pQxWgpJCE
license:              BSD-3-Clause
maintainer:           matthewtpickering@gmail.com
author:               Matthew Pickering
synopsis:             Specify refactorings to perform with apply-refact
description:
    This library provides a datatype which can be interpreted by apply-refact. It exists
    as a seperate library so that applications can specify refactorings without depending on GHC.

category:             Development
abi:                  906160511db2fe2329047c49c37a6528
exposed:              True
exposed-modules:      Refact.Types
import-dirs:          /usr/lib/ghc-8.10.5/site-local/refact-0.3.0.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/refact-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/refact-0.3.0.2
hs-libraries:         HSrefact-0.3.0.2-JKNk3jm7RIRD7pQxWgpJCE
depends:              base-4.14.2.0
haddock-interfaces:   /usr/share/doc/haskell-refact/html/refact.haddock
haddock-html:         /usr/share/doc/haskell-refact/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

